@@ -3,7 +3,6 @@ use strict;
 use Test::TCP;
 use Test::More;
 use AnyEvent::Redis;
-use FindBin;
 
 use base qw(Exporter);
 our @EXPORT = qw(test_redis);
@@ -12,7 +11,7 @@ sub test_redis(&) {
     my $cb = shift;
 
     chomp(my $redis_server = `which redis-server`);
-    unless ($redis_server && -e $redis_server && -x _) {
+    unless ($redis_server) {
         plan skip_all => 'redis-server not found in your PATH';
     }
 
@@ -24,21 +23,19 @@ sub test_redis(&) {
         },
         client => sub {
             my $port = shift;
-            my $r = AnyEvent::Redis->new(host => "127.0.0.1", port => $port);
-            $cb->($r, $port);
+            my $r = AnyEvent::Redis->new("127.0.0.1:$port");
+            $cb->($r);
         };
 }
 
 sub rewrite_redis_conf {
     my $port = shift;
-    my $dir  = $FindBin::Bin;
 
     open my $in, "<", "t/redis.conf.base" or die $!;
     open my $out, ">", "t/redis.conf" or die $!;
 
     while (<$in>) {
         s/__PORT__/$port/;
-        s/__DIR__/$dir/;
         print $out $_;
     }
 }
